
# zyx

Zyx is a library written in Python with the sole purpose of bringing large language models and prompting
into your development workflow, without a tough learning curve, or large overhead. It is designed with a focus on being lightweight with a minimal and 
comfy API style.

To get started, you can install zyx using pip, or by cloning the repository and building from 
source.

**Install From Pip**
```bash
pip install zyx
```

**Install From Source**
```bash
git clone https://github.com/hsaeed3/zyx
cd zyx
pip install .
```

This library was built using the creations of brilliant teams, here are the main libraries zyx is built on top of:

- [Instructor]()
- [Pydantic]()
- [LiteLLM]()
- [DSPY]()
- [Chroma]()
- [Ollama]()
- [Peewee]()
- [FastAPI]()
- [FastUI]()
- [SQLModel]()